@@ -3,7 +3,7 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindBackgroundAttachment {
-    kind: KeywordOnly,
+    kind: StandardValue,
 }
 
 crate::macros::sealed::keyword_instance!(TailwindBackgroundAttachment => "background-attachment");
@@ -11,10 +11,12 @@ crate::macros::sealed::keyword_instance!(TailwindBackgroundAttachment => "backgr
 impl Display for TailwindBackgroundAttachment {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "bg-")?;
-        let s = self.kind.get_properties();
-        match s {
-            s @ ("fixed" | "local" | "scroll") => write!(f, "{}", s),
-            _ => write!(f, "attach-{}", s),
+        match &self.kind {
+            StandardValue::Keyword(s) => match s.as_str() {
+                s @ ("fixed" | "local" | "scroll") => write!(f, "{}", s),
+                _ => write!(f, "attach-{}", s),
+            },
+            StandardValue::Arbitrary(s) => s.write_class(f, "attach-"),
         }
     }
 }
@@ -22,11 +24,11 @@ impl Display for TailwindBackgroundAttachment {
 impl TailwindBackgroundAttachment {
     /// <https://tailwindcss.com/docs/background-attachment>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parser("bg-attach", &Self::check_valid)(pattern, arbitrary)? })
+        Ok(Self { kind: StandardValue::parser("bg-attach", &Self::check_valid)(pattern, arbitrary)? })
     }
     /// <https://tailwindcss.com/docs/background-attachment>
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
+        StandardValue::parse_arbitrary(arbitrary).map(|kind| Self { kind })
     }
     /// <https://developer.mozilla.org/en-US/docs/Web/CSS/background-attachment#syntax>
     pub fn check_valid(mode: &str) -> bool {
