@@ -5,6 +5,7 @@ use super::*;
 pub struct TailwindBackgroundColor {
     color: TailwindColor,
 }
+crate::macros::sealed::color_instance!(TailwindBackgroundColor);
 
 impl Display for TailwindBackgroundColor {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -13,7 +14,7 @@ impl Display for TailwindBackgroundColor {
 }
 
 impl TailwindInstance for TailwindBackgroundColor {
-    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+    fn attributes(&self, ctx: &TailwindBuilder) -> CssAttributes {
         css_attributes! {
             "background-color" => self.color.get_properties(ctx)
         }
