@@ -10,8 +10,8 @@ pub use self::{
     size::TailwindBackgroundSize,
 };
 use crate::{
-    css_attributes, syntax_error, AnchorPoint, CssAttributes, KeywordOnly, Result, TailwindArbitrary, TailwindBuilder,
-    TailwindColor, TailwindInstance,
+    css_attributes, AnchorPoint, CssAttributes, Result, StandardValue, TailwindArbitrary, TailwindBuilder, TailwindColor,
+    TailwindInstance,
 };
 use std::{
     collections::BTreeSet,
@@ -27,5 +27,3 @@ mod origin;
 mod position;
 mod repeat;
 mod size;
-#[cfg(test)]
-mod test;
