@@ -1,19 +1,14 @@
+use crate::StandardValue;
+
 use super::*;
 
 #[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindBorderStyle {
-    kind: String,
+    kind: StandardValue,
 }
 
-impl<T> From<T> for TailwindBorderStyle
-where
-    T: Into<String>,
-{
-    fn from(kind: T) -> Self {
-        Self { kind: kind.into() }
-    }
-}
+crate::macros::sealed::keyword_instance!(TailwindBorderStyle => "border-style");
 
 impl Display for TailwindBorderStyle {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -21,20 +16,10 @@ impl Display for TailwindBorderStyle {
     }
 }
 
-impl TailwindInstance for TailwindBorderStyle {
-    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
-        css_attributes! {
-            "border-style" => self.kind
-        }
-    }
-}
-
 impl TailwindBorderStyle {
     /// https://tailwindcss.com/docs/object-fit
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after object");
-        let kind = pattern.join("-");
-        debug_assert!(Self::check_valid(&kind));
+        let kind = StandardValue::parser("border-style", &Self::check_valid)(pattern, arbitrary)?;
         Ok(Self { kind })
     }
     /// https://developer.mozilla.org/en-US/docs/Web/CSS/border-style#syntax
