@@ -1,9 +1,9 @@
 use super::*;
 
-#[doc = include_str!("readme.md")]
+#[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindBrightness {
-    percent: IntegerOnly,
+    percent: NumericValue,
     backdrop: Backdrop,
 }
 
@@ -16,20 +16,17 @@ impl Display for TailwindBrightness {
 
 impl TailwindInstance for TailwindBrightness {
     fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
-        let class = self.backdrop.filter();
-        let value = match &self.percent {
-            IntegerOnly::Number(n) => format!("brightness({}%)", n),
-            IntegerOnly::Arbitrary(n) => format!("brightness({})", n),
-        };
-        css_attributes! {
-            class => value
-        }
+        let n = self.percent.get_properties(|f| format!("{}%", f));
+        self.backdrop.get_filter(format!("brightness({})", n))
     }
 }
 
 impl TailwindBrightness {
     pub fn parse(rest: &[&str], arbitrary: &TailwindArbitrary, backdrop: bool) -> Result<Self> {
-        let percent = IntegerOnly::parser("brightness")(rest, arbitrary)?;
+        let percent = match rest {
+            [] if arbitrary.is_none() => 100u32.into(),
+            _ => NumericValue::positive_parser("brightness", |_| false)(rest, arbitrary)?,
+        };
         Ok(Self { percent, backdrop: Backdrop::from(backdrop) })
     }
 }
