@@ -1,14 +1,13 @@
 use super::*;
 
-#[doc = include_str!("readme.md")]
+#[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindInvert {
-    percent: IntegerOnly,
+    percent: NumericValue,
     backdrop: Backdrop,
 }
 impl Display for TailwindInvert {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        debug_assert!(self.percent <= 100);
         self.backdrop.write(f)?;
         write!(f, "invert-{}", self.percent)
     }
@@ -16,22 +15,17 @@ impl Display for TailwindInvert {
 
 impl TailwindInstance for TailwindInvert {
     fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
-        let class = self.backdrop.filter();
-        let value = match &self.percent {
-            IntegerOnly::Number(n) => format!("invert({}%)", n),
-            IntegerOnly::Arbitrary(n) => format!("invert({})", n),
-        };
-        css_attributes! {
-            class => value
-        }
+        let n = self.percent.get_properties(|f| format!("{}%", f));
+        self.backdrop.get_filter(format!("invert({})", n))
     }
 }
 
 impl TailwindInvert {
+    /// <https://tailwindcss.com/docs/invert>
     pub fn parse(rest: &[&str], arbitrary: &TailwindArbitrary, backdrop: bool) -> Result<Self> {
         let percent = match rest {
-            [] if arbitrary.is_none() => 100usize.into(),
-            _ => IntegerOnly::parser("invert")(rest, arbitrary)?,
+            [] if arbitrary.is_none() => 100u32.into(),
+            _ => NumericValue::positive_parser("invert", |_| false)(rest, arbitrary)?,
         };
         Ok(Self { percent, backdrop: Backdrop::from(backdrop) })
     }
