@@ -1,5 +1,4 @@
 use super::*;
-use crate::TailwindDisplay;
 
 pub(crate) mod flex_direction;
 pub(crate) mod flex_wrap;
@@ -7,7 +6,7 @@ pub(crate) mod flex_wrap;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindFlex {
-    kind: KeywordOnly,
+    kind: NumericValue,
 }
 
 impl Display for TailwindFlex {
@@ -18,8 +17,9 @@ impl Display for TailwindFlex {
 
 impl TailwindInstance for TailwindFlex {
     fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
+        let flex = self.kind.get_properties(|f| f.to_string());
         css_attributes! {
-            "flex" => self.kind.get_properties()
+            "flex" => flex
         }
     }
 }
@@ -39,20 +39,23 @@ impl TailwindFlex {
             ["col", "reverse"] => TailwindFlexDirection::from("column-reverse").boxed(),
             ["direction", rest @ ..] => TailwindFlexDirection::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/flex-wrap
-            ["wrap"] => TailwindFlexWrap::from("wrap").boxed(),
-            ["wrap", "reverse"] => TailwindFlexWrap::from("wrap-reverse").boxed(),
+            ["wrap", rest @ ..] => TailwindFlexWrap::parse(rest, arbitrary)?.boxed(),
             ["nowrap"] => TailwindFlexWrap::from("nowrap").boxed(),
             // https://tailwindcss.com/docs/flex
             _ => Self::parse(pattern, arbitrary)?.boxed(),
         };
         Ok(out)
     }
+    /// <https://tailwindcss.com/docs/flex>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<TailwindFlex> {
-        Ok(TailwindFlex { kind: KeywordOnly::parser("flex", &Self::check_valid)(pattern, arbitrary)? })
+        let kind = NumericValue::positive_parser("flex", &Self::check_valid)(pattern, arbitrary)?;
+        Ok(TailwindFlex { kind })
     }
+    /// dispatch to [flex](https://developer.mozilla.org/en-US/docs/Web/CSS/flex)
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
+        NumericValue::parse_arbitrary(arbitrary).map(|kind| Self { kind })
     }
+    /// <https://developer.mozilla.org/en-US/docs/Web/CSS/flex#syntax>
     pub fn check_valid(mode: &str) -> bool {
         let set = BTreeSet::from_iter(vec!["auto", "inherit", "initial", "initial", "none", "revert", "unset"]);
         set.contains(mode)
