@@ -3,7 +3,7 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindPlaceContent {
-    kind: KeywordOnly,
+    kind: StandardValue,
 }
 
 crate::macros::sealed::keyword_instance!(TailwindPlaceContent => "place-content");
@@ -17,11 +17,11 @@ impl Display for TailwindPlaceContent {
 impl TailwindPlaceContent {
     /// <https://tailwindcss.com/docs/place-content>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parser("place-content", &Self::check_valid)(pattern, arbitrary)? })
+        Ok(Self { kind: StandardValue::parser("place-content", &Self::check_valid)(pattern, arbitrary)? })
     }
     /// dispatch to [place-items](https://developer.mozilla.org/en-US/docs/Web/CSS/place-content)
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
+        StandardValue::parse_arbitrary(arbitrary).map(|kind| Self { kind })
     }
     /// <https://developer.mozilla.org/en-US/docs/Web/CSS/place-content#syntax>
     pub fn check_valid(mode: &str) -> bool {
