@@ -3,7 +3,7 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindSnapType {
-    kind: KeywordOnly,
+    kind: StandardValue,
 }
 
 crate::macros::sealed::keyword_instance!(TailwindSnapType => "scroll-snap-type");
@@ -15,21 +15,10 @@ impl Display for TailwindSnapType {
 }
 
 impl TailwindSnapType {
-    /// https://tailwindcss.com/docs/scroll-snap-type
+    /// <https://tailwindcss.com/docs/scroll-snap-type>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        match pattern {
-            [] => Self::parse_arbitrary(arbitrary),
-            _ => {
-                let s = pattern.join("-");
-                debug_assert!(Self::check_valid(&s));
-                Ok(Self { kind: KeywordOnly::Standard(s) })
-            },
-        }
-    }
-    /// https://tailwindcss.com/docs/scroll-snap-type
-    pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        debug_assert!(arbitrary.is_some());
-        Ok(Self { kind: KeywordOnly::Arbitrary(arbitrary.to_string()) })
+        let kind = StandardValue::parser("scroll-type", &Self::check_valid)(pattern, arbitrary)?;
+        Ok(Self { kind })
     }
     /// https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-type#syntax
     pub fn check_valid(mode: &str) -> bool {
