@@ -3,20 +3,20 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindBoxDecoration {
-    kind: KeywordOnly,
+    kind: StandardValue,
 }
 
-crate::macros::sealed::keyword_instance!(TailwindBoxDecoration => "box-break");
+crate::macros::sealed::keyword_instance!(TailwindBoxDecoration => "box-decoration-break");
 
 impl Display for TailwindBoxDecoration {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match &self.kind {
-            KeywordOnly::Standard(s) => match s.as_str() {
+            StandardValue::Keyword(s) => match s.as_str() {
                 "clone" => write!(f, "box-clone"),
                 "slice" => write!(f, "box-slice"),
                 _ => write!(f, "box-break-{}", s),
             },
-            KeywordOnly::Arbitrary(s) => write!(f, "box-break-[{}]", s),
+            StandardValue::Arbitrary(s) => s.write_class(f, "box-break-"),
         }
     }
 }
@@ -24,11 +24,11 @@ impl Display for TailwindBoxDecoration {
 impl TailwindBoxDecoration {
     /// <https://tailwindcss.com/docs/box-decoration-break>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parser("box-break", &Self::check_valid)(pattern, arbitrary)? })
+        Ok(Self { kind: StandardValue::parser("box-break", &Self::check_valid)(pattern, arbitrary)? })
     }
     /// dispatch to [box-decoration-break](https://developer.mozilla.org/en-US/docs/Web/CSS/box-decoration-break)
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
+        StandardValue::parse_arbitrary(arbitrary).map(|kind| Self { kind })
     }
     /// <https://developer.mozilla.org/en-US/docs/Web/CSS/box-decoration-break#syntax>
     pub fn check_valid(mode: &str) -> bool {
