@@ -11,14 +11,14 @@ pub use self::{
     object::*,
     overflow::TailwindOverflow,
     overscroll::TailwindOverscroll,
-    placement::{bottom::TailwindBottom, inset::TailwindInset, left::TailwindLeft, right::TailwindRight, top::TailwindTop},
+    placement::*,
     position::TailwindPosition,
     visible::TailwindVisibility,
     z_index::TailwindZIndex,
 };
 use crate::{
-    css_attributes, syntax_error, AnchorPoint, CssAttributes, CssBehavior, KeywordOnly, LengthUnit, Negative, Result,
-    TailwindArbitrary, TailwindBuilder, TailwindInstance,
+    css_attributes, syntax_error, AnchorPoint, AxisXY, CssAttributes, LengthUnit, Negative, Result, StandardValue,
+    TailwindArbitrary, TailwindBuilder, TailwindInstance, UnitValue,
 };
 use std::{
     collections::BTreeSet,
@@ -39,7 +39,5 @@ mod overflow;
 mod overscroll;
 mod placement;
 mod position;
-#[cfg(test)]
-mod test;
 mod visible;
 mod z_index;
