@@ -39,7 +39,7 @@ impl TailwindScrollMargin {
             ["my", rest @ ..] => (SpacingAxis::new("scroll-my", &["scroll-margin"]), rest),
             _ => return syntax_error!("Unknown scroll-margin axis"),
         };
-        let size = SpacingSize::parse(rest, arbitrary)?;
+        let size = SpacingSize::parse(rest, arbitrary, &Self::check_valid)?;
         Ok(Self { negative, axis, size })
     }
     /// https://tailwindcss.com/docs/scroll-margin#arbitrary-values
@@ -47,4 +47,9 @@ impl TailwindScrollMargin {
         let size = SpacingSize::parse_arbitrary(arbitrary)?;
         Ok(Self { negative, axis, size })
     }
+    /// https://developer.mozilla.org/en-US/docs/Web/CSS/padding#syntax
+    pub fn check_valid(mode: &str) -> bool {
+        let set = BTreeSet::from_iter(vec!["auto", "inherit", "initial", "revert", "unset"]);
+        set.contains(mode)
+    }
 }
