@@ -13,15 +13,9 @@ impl TailwindStroke {
         let color = |color| TailwindStrokeColor::from(color).boxed();
         let out = match str {
             // https://tailwindcss.com/docs/text-decoration-color
-            ["current"] => color(TailwindColor::Current),
-            ["transparent"] => color(TailwindColor::Transparent),
-            ["inherit"] => color(TailwindColor::Inherit),
             ["black"] => color(TailwindColor::Black),
             ["white"] => color(TailwindColor::White),
-            ["color"] => {
-                debug_assert!(arbitrary.is_some());
-                color(TailwindColor::parse_arbitrary(arbitrary)?)
-            },
+            ["color"] => color(TailwindColor::parse_arbitrary(arbitrary)?),
             ["color", rest] => {
                 let a = TailwindArbitrary::from(*rest);
                 color(TailwindColor::parse_arbitrary(&a)?)
