@@ -1,10 +1,10 @@
 use super::*;
-use crate::KeywordOnly;
+use crate::StandardValue;
 
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindFontFamily {
-    kind: KeywordOnly,
+    kind: StandardValue,
 }
 
 crate::macros::sealed::keyword_instance!(TailwindFontFamily => "font-family");
