@@ -1,3 +1,4 @@
+pub(crate) use self::list::list_adaptor;
 pub use self::{
     align::TailwindAlign,
     breaking::TailwindBreak,
@@ -11,7 +12,7 @@ pub use self::{
     },
     indent::TailwindIndent,
     leading::TailwindLeading,
-    list::{list_position::TailwindListPosition, list_type::TailwindListStyle, TailwindList},
+    list::{list_position::TailwindListPosition, list_type::TailwindListStyle},
     text::{
         text_adaptor, text_align::TailwindTextAlignment, text_color::TailwindTextColor, text_overflow::TailwindTextOverflow,
         text_transform::TailwindTextTransform,
@@ -21,8 +22,8 @@ pub use self::{
     whitespace::TailwindWhiteSpace,
 };
 use crate::{
-    css_attributes, syntax_error, CssAttributes, CssBehavior, KeywordOnly, LengthUnit, Result, TailwindArbitrary,
-    TailwindBreakAfter, TailwindBreakBefore, TailwindBreakInside, TailwindBuilder, TailwindColor, TailwindInstance,
+    css_attributes, syntax_error, CssAttributes, LengthUnit, Result, StandardValue, TailwindArbitrary, TailwindBreakAfter,
+    TailwindBreakBefore, TailwindBreakInside, TailwindBuilder, TailwindColor, TailwindInstance,
 };
 use std::{
     collections::BTreeSet,
