@@ -3,7 +3,7 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindTextAlignment {
-    kind: KeywordOnly,
+    kind: StandardValue,
 }
 
 crate::macros::sealed::keyword_instance!(TailwindTextAlignment => "text-align");
@@ -17,11 +17,12 @@ impl Display for TailwindTextAlignment {
 impl TailwindTextAlignment {
     /// <https://tailwindcss.com/docs/will-change>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parser("font-align", &Self::check_valid)(pattern, arbitrary)? })
+        let kind = StandardValue::parser("font-align", &Self::check_valid)(pattern, arbitrary)?;
+        Ok(Self { kind })
     }
     /// dispatch to [text-align](https://developer.mozilla.org/en-US/docs/Web/CSS/text-align)
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
+        StandardValue::parse_arbitrary(arbitrary).map(|kind| Self { kind })
     }
     /// https://developer.mozilla.org/en-US/docs/Web/CSS/text-align#syntax
     pub fn check_valid(mode: &str) -> bool {
