@@ -4,6 +4,7 @@ impl TailwindBuilder {
     ///
     #[inline]
     pub fn clear(&mut self) {
-        self.objects.clear()
+        self.objects.clear();
+        self.bundles.clear();
     }
 }
