@@ -14,12 +14,13 @@ impl TailwindBuilder {
 impl Default for TailwindBuilder {
     fn default() -> Self {
         Self {
-            obfuscate: false,
             objects: Default::default(),
+            bundles: Default::default(),
             screens: BreakPointSystem::builtin(),
             palettes: PaletteSystem::builtin(),
             fonts: FontSystem::builtin(),
             preflight: PreflightSystem::default(),
+            effects: EffectSystem::builtin(),
         }
     }
 }
