@@ -3,7 +3,7 @@ mod palette;
 mod palette_system;
 
 pub use self::{color::TailwindColor, palette::Palette, palette_system::PaletteSystem};
-use crate::{syntax_error, CssBehavior, Result, TailwindArbitrary, TailwindBuilder};
+use crate::{syntax_error, Result, TailwindArbitrary, TailwindBuilder};
 use css_color::Srgb;
 use std::{
     collections::{BTreeMap, HashMap},
