@@ -1,7 +1,7 @@
 use super::*;
 
-#[derive(Copy, Clone, Debug)]
-pub enum InlineMode {
+#[derive(Debug, Clone, Ord, PartialOrd, Eq, PartialEq, Hash)]
+pub enum CssInlineMode {
     /// ```html
     /// <img class="tailwind"/>
     /// ```
@@ -24,7 +24,7 @@ pub enum InlineMode {
     DataValue,
 }
 
-impl Default for InlineMode {
+impl Default for CssInlineMode {
     fn default() -> Self {
         Self::None
     }
