@@ -1,5 +1,3 @@
-use log::error;
-
 use super::*;
 
 impl Display for TailwindInstruction {
@@ -9,7 +7,7 @@ impl Display for TailwindInstruction {
         }
         self.negative.write(f)?;
         match self.arbitrary.is_some() {
-            true => write!(f, "{}-[{}]", self.elements, self.arbitrary),
+            true => write!(f, "{}-{}", self.elements, self.arbitrary.get_class()),
             false => write!(f, "{}", self.elements),
         }
     }
@@ -19,10 +17,11 @@ impl TailwindInstance for TailwindInstruction {
     fn attributes(&self, ctx: &TailwindBuilder) -> CssAttributes {
         let mut out = CssAttributes::default();
         match self.get_instance() {
-            Ok(o) => out.extend(o.attributes(ctx)),
+            Ok(o) => {
+                out += o.attributes(ctx);
+            },
             Err(e) => {
-                #[cfg(debug_assertions)]
-                error!("{:?}", e)
+                unimplemented!("{}", e);
             },
         }
         out
