@@ -1,13 +1,9 @@
 use super::*;
 
-#[derive(Copy, Clone, Debug)]
-pub struct Negative(bool);
+mod traits;
 
-impl From<bool> for Negative {
-    fn from(n: bool) -> Self {
-        Self(n)
-    }
-}
+#[derive(Copy, Clone, Debug)]
+pub struct Negative(pub(crate) bool);
 
 impl Negative {
     pub fn write(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -19,10 +15,7 @@ impl Negative {
     pub fn get_properties(&self, value: &str) -> String {
         match self.0 {
             true => format!("-{}", value),
-            false => format!("{}", value),
+            false => value.to_string(),
         }
     }
-    pub fn unwrap(&self) -> bool {
-        self.0
-    }
 }
